package
Version:
v0.0.0-...-19d8e19
Opens a new window with list of versions in this module.
Published: Jun 24, 2025
License: Apache-2.0
Opens a new window with license information.
Imports: 8
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
GetAppInfo retrieves and returns application information in JSON format
type ConfigUri struct {
AppName string `uri:"app_name" binding:"required"`
ConfigKey string `uri:"config_key" binding:"required"`
}
type GetConfigResp struct {
Type string `json:"type"`
Value any `json:"value"`
TS int64 `json:"ts"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.